from cowinvacc import CowinAPIsData

obj = CowinAPIsData()
# states_dict = obj.States_dict()
# states_df = obj.States_df()
# states_list = obj.States_list()
# dist_df = obj.Districts_df()
# districts_dict = obj.Districts_dict()
# districts_list = obj.Districts_list()
# randomDist = input()
# a = obj.districts_id(randomDist)
district_id=372
numdays=5
POST_CODE = 415709
df1 = obj.centersBydistId(district_id, numdays)
# df2 = obj.centersByPinCode(POST_CODE)
# print(states_dict)
# print(states_df)
# print(states_list)
# print(dist_df.head())
# print(districts_dict)
# print(districts_list)
# print(a)
print(df1)
# print(df2)

#   project_urls={  # Optional
#         'Bug Reports': '',
#         'Source': '',
#     },